/*
 * Copyright (C) The Apache Software Foundation. All rights reserved.
 *
 * This software is published under the terms of the Apache Software License
 * version 1.1, a copy of which has been included with this distribution in
 * the LICENSE file.
 */
package org.apache.avalon.excalibur.extension.test;

import java.io.File;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.jar.Manifest;
import junit.framework.TestCase;
import org.apache.avalon.excalibur.extension.DefaultPackageRepository;
import org.apache.avalon.excalibur.extension.Extension;
import org.apache.avalon.excalibur.extension.ExtensionUtil;
import org.apache.avalon.excalibur.extension.OptionalPackage;
import org.apache.avalon.excalibur.extension.PackageManager;
import org.apache.avalon.excalibur.extension.PackageRepository;

/**
 * TestCases for PackageRepository.
 *
 * @author <a href="mailto:donaldp@apache.org">Peter Donald</a>
 * @version $Revision: 1.2 $ $Date: 2001/09/03 07:53:34 $
 */
public class PackageRepositoryTestCase
    extends TestCase
{
    public PackageRepositoryTestCase( String name )
    {
        super( name );
    }

    public void testScanDependencies()
        throws Exception
    {
        final PackageRepository repository = newPackagerepository();
        final PackageRepository[] repositorys = new PackageRepository[] { repository };
        final PackageManager manager = new PackageManager( repositorys );

        final Manifest manifest2 = getManifest( "manifest-2.mf" );
        final Extension extension1 = ExtensionUtil.getRequiredExtensions( manifest2 )[ 0 ];

        final ArrayList dependencies = new ArrayList();
        final ArrayList unsatisfied = new ArrayList();

        ExtensionUtil.scanDependencies( manager, extension1, dependencies, unsatisfied );
        System.out.println( "dependencies: " + dependencies );
        
        assertEquals( "dependencies Count", 2, dependencies.size() );
        assertEquals( "unsatisfied Count", 0, unsatisfied.size() );

        final int size = dependencies.size();
        for( int i = 0; i < size; i++ )
        {
            final OptionalPackage optionalPackage = (OptionalPackage)dependencies.get( i );
            final Extension[] extensions = optionalPackage.getAvailableExtensions();
            for( int j = 0; j < extensions.length; j++ )
            {
                final String name = extensions[ j ].getExtensionName();
                if( !name.equals( "excalibur.required1" ) &&
                    !name.equals( "excalibur.required2" ) )
                {
                    assertTrue( "Unexpected extension: " + name, false );
                }                
            }
        }
    }

    private Manifest getManifest( final String name )
        throws Exception
    {
        final InputStream inputStream = getClass().getResourceAsStream( name );
        return new Manifest( inputStream );
    }

    private PackageRepository newPackagerepository()
        throws Exception
    {
        final TestPackageRepository repository = new TestPackageRepository();
        repository.addEntry( "manifest-1.mf" );
        repository.addEntry( "manifest-2.mf" );
        repository.addEntry( "manifest-3.mf" );
        repository.addEntry( "manifest-4.mf" );
        repository.addEntry( "manifest-5.mf" );
        repository.addEntry( "manifest-6.mf" );
        repository.addEntry( "manifest-7.mf" );
        repository.addEntry( "manifest-8.mf" );
        return repository;
    }
}

class TestPackageRepository
    extends DefaultPackageRepository
{
    TestPackageRepository()
        throws Exception
    {
        super( new File( "." ) );
    }

    void addEntry( final String manifestLocation )
        throws Exception
    {
        final InputStream inputStream = getClass().getResourceAsStream( manifestLocation );
        final Manifest manifest = new Manifest( inputStream );
        final File file = new File( manifestLocation );
        final Extension[] available = ExtensionUtil.getAvailableExtensions( manifest );
        final Extension[] required = ExtensionUtil.getRequiredExtensions( manifest );

        cacheOptionalPackage( new OptionalPackage( file, available, required ) );
    }
}
