package org.apache.avalon.excalibur.i18n.test;

import junit.framework.TestCase;
import org.apache.log.Hierarchy;
import org.apache.avalon.framework.configuration.DefaultConfiguration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.excalibur.i18n.XMLResourceBundleFactory;

public class XMLResourceBundleFactoryTestCase
    extends TestCase
{
    public XMLResourceBundleFactoryTestCase( String name )
    {
        super( name );
    }

    public void testConfigureDefault()
    {
        XMLResourceBundleFactory factory = new XMLResourceBundleFactory();
        factory.setLogger(Hierarchy.getDefaultHierarchy().getLoggerFor("XMLResourceBundle"));
        try
        {
            factory.configure(new DefaultConfiguration("name", "location"));
        }
        catch (ConfigurationException e)
        {
            fail(e.getMessage());
        }
        assertTrue("The default root directory is not empty!",
            factory.getDirectory().equals(""));
        assertTrue("The default setting should be not to pre-load all resources",
            !factory.cacheAtStartup());
    }

    public void testConfigure()
    {
        XMLResourceBundleFactory factory = new XMLResourceBundleFactory();
        factory.setLogger(Hierarchy.getDefaultHierarchy().getLoggerFor("XMLResourceBundle"));
        DefaultConfiguration configuration = new DefaultConfiguration("name", "location");
        configuration.setAttribute(XMLResourceBundleFactory.ConfigurationKeys.CACHE_AT_STARTUP, "true");
        DefaultConfiguration dirConf = new DefaultConfiguration(XMLResourceBundleFactory.ConfigurationKeys.ROOT_DIRECTORY, "location");
        dirConf.setValue("test dir");
        configuration.addChild(dirConf);
        try
        {
            factory.configure(configuration);
        }
        catch (ConfigurationException e)
        {
            fail(e.getMessage());
        }
        assertTrue("The root directory is not set correctly!",
            factory.getDirectory().equals("test dir"));
        assertTrue("The pre-loading of all resources is not set correctly",
            factory.cacheAtStartup());
    }
}